// script.js
// URL of the GitHub Gist containing the data
const gistUrl =
  'https://gist.githubusercontent.com/RAGHu-789/5510fb80aaae9108dc9573a345584ff0/raw/4a8b1516b3944a3887f3d4bfb09cc4d50b6c033d/gistfile1.txt';

// Load data from the Gist URL
fetch(gistUrl)
  .then((response) => response.json())
  .then((data) => {
    // Set up the SVG and margins
    const margin = {
        top: 20,
        right: 20,
        bottom: 30,
        left: 50,
      },
      width = 600 - margin.left - margin.right,
      height = 400 - margin.top - margin.bottom;

    const svg = d3
      .select('#chart')
      .attr('width', width + margin.left + margin.right)
      .attr('height', height + margin.top + margin.bottom)
      .append('g')
      .attr(
        'transform',
        'translate(' + margin.left + ',' + margin.top + ')',
      );

    // X and Y scales
    const x = d3
      .scaleBand()
      .range([0, width])
      .domain(data.map((d) => d.month))
      .padding(0.1);

    const y = d3
      .scaleLinear()
      .range([height, 0])
      .domain([0, d3.max(data, (d) => d.value)]);

    // Area generator
    const area = d3
      .area()
      .x((d) => x(d.month))
      .y0(y(0))
      .y1((d) => y(d.value));

    // Add the area path
    svg
      .append('path')
      .datum(data)
      .attr('fill', 'yellow')
      .attr('d', area);

    // Add X axis
    svg
      .append('g')
      .attr('transform', 'translate(0,' + height + ')')
      .call(d3.axisBottom(x));

    // Add Y axis
    svg.append('g').call(d3.axisLeft(y));

    // Add X axis label
    svg
      .append('text')
      .attr(
        'transform',
        'translate(' +
          width / 2 +
          ' ,' +
          (height + margin.top + 10) +
          ')',
      )
      .style('text-anchor', 'middle')
      .text('Month');

    // Add Y axis label
    svg
      .append('text')
      .attr('transform', 'rotate(-90)')
      .attr('y', 0 - margin.left)
      .attr('x', 0 - height / 2)
      .attr('dy', '1em')
      .style('text-anchor', 'middle')
      .text('Value');
  })
  .catch((error) => {
    console.error('Error fetching data:', error);
  });
